@@ -1,6 +1,3 @@
-import sys
-
-
 class fopen(object):
 
     def __init__(self, filename, mode, encoding, newline=None):
@@ -11,14 +8,11 @@ class fopen(object):
         self._fp = None
 
     def __enter__(self):
-        if sys.version_info[0] < 3:
-            self._fp = open(self._filename, self._mode)
-        else:
-            self._fp = open(self._filename,
-                            self._mode,
-                            encoding=self._encoding,
-                            newline=self._newline,
-                            errors='replace')
+        self._fp = open(self._filename,
+                        self._mode,
+                        encoding=self._encoding,
+                        newline=self._newline,
+                        errors='replace')
 
         return self._fp
 
