@@ -104,7 +104,7 @@ DRIVER_HEARTBEAT(
   vcan0  1F4   [4]  01 02 03 04 ::
 IO_DEBUG(
     IO_DEBUG_test_unsigned: 1,
-    IO_DEBUG_test_enum: 'two',
+    IO_DEBUG_test_enum: IO_DEBUG_test2_enum_two,
     IO_DEBUG_test_signed: 3,
     IO_DEBUG_test_float: 2.0
 )
@@ -121,7 +121,12 @@ IO_DEBUG(
                     self.assertEqual(actual_output, expected_output)
 
     def test_decode_timestamp_absolute(self):
-        argv = ['cantools', 'decode', 'tests/files/dbc/socialledge.dbc']
+        argv = [
+            'cantools',
+            'decode',
+            '--prune',
+            'tests/files/dbc/socialledge.dbc'
+        ]
         input_data = """\
  (2020-12-19 12:04:45.485261)  vcan0  0C8   [8]  F0 00 00 00 00 00 00 00
  (2020-12-19 12:04:48.597222)  vcan0  064   [8]  F0 01 FF FF FF FF FF FF
@@ -146,7 +151,7 @@ DRIVER_HEARTBEAT(
  (2020-12-19 12:04:56.805087)  vcan0  1F4   [4]  01 02 03 04 ::
 IO_DEBUG(
     IO_DEBUG_test_unsigned: 1,
-    IO_DEBUG_test_enum: 'two',
+    IO_DEBUG_test_enum: two,
     IO_DEBUG_test_signed: 3,
     IO_DEBUG_test_float: 2.0
 )
@@ -163,7 +168,12 @@ IO_DEBUG(
                     self.assertEqual(actual_output, expected_output)
 
     def test_decode_timestamp_zero(self):
-        argv = ['cantools', 'decode', 'tests/files/dbc/socialledge.dbc']
+        argv = [
+            'cantools',
+            'decode',
+            '--prune',
+            'tests/files/dbc/socialledge.dbc'
+        ]
         input_data = """\
  (000.000000)  vcan0  0C8   [8]  F0 00 00 00 00 00 00 00
  (002.047817)  vcan0  064   [8]  F0 01 FF FF FF FF FF FF
@@ -188,7 +198,7 @@ DRIVER_HEARTBEAT(
  (012.831664)  vcan0  1F4   [4]  01 02 03 04 ::
 IO_DEBUG(
     IO_DEBUG_test_unsigned: 1,
-    IO_DEBUG_test_enum: 'two',
+    IO_DEBUG_test_enum: two,
     IO_DEBUG_test_signed: 3,
     IO_DEBUG_test_float: 2.0
 )
@@ -231,6 +241,7 @@ CanFd(
         argv = [
             'cantools',
             'decode',
+            '--prune',
             'tests/files/dbc/socialledge.dbc'
         ]
         input_data = """\
@@ -261,7 +272,7 @@ DRIVER_HEARTBEAT(
 (1594172462.356874) vcan0 1F4#01020304 ::
 IO_DEBUG(
     IO_DEBUG_test_unsigned: 1,
-    IO_DEBUG_test_enum: 'two',
+    IO_DEBUG_test_enum: two,
     IO_DEBUG_test_signed: 3,
     IO_DEBUG_test_float: 2.0
 )
@@ -281,6 +292,7 @@ IO_DEBUG(
         argv = [
             'cantools',
             'decode',
+            '--prune',
             '--single-line',
             'tests/files/dbc/socialledge.dbc'
         ]
@@ -299,7 +311,7 @@ IO_DEBUG(
   vcan0  064   [10]  F0 01 FF FF FF FF FF FF FF FF :: DRIVER_HEARTBEAT(DRIVER_HEARTBEAT_cmd: 240)
   vcan0  ERROR
 
-  vcan0  1F4   [4]  01 02 03 04 :: IO_DEBUG(IO_DEBUG_test_unsigned: 1, IO_DEBUG_test_enum: 'two', IO_DEBUG_test_signed: 3, IO_DEBUG_test_float: 2.0)
+  vcan0  1F4   [4]  01 02 03 04 :: IO_DEBUG(IO_DEBUG_test_unsigned: 1, IO_DEBUG_test_enum: two, IO_DEBUG_test_signed: 3, IO_DEBUG_test_float: 2.0)
   vcan0  1F3   [3]  01 02 03 :: Unknown frame id 499 (0x1f3)
 """
 
@@ -316,6 +328,7 @@ IO_DEBUG(
         argv = [
             'cantools',
             'decode',
+            '--prune',
             '--single-line',
             'tests/files/dbc/socialledge.dbc'
         ]
@@ -334,7 +347,7 @@ IO_DEBUG(
 (1594172462.126542) vcan0 064#F001FFFFFFFFFFFFFFFF :: DRIVER_HEARTBEAT(DRIVER_HEARTBEAT_cmd: 240)
 (1594172462.127684) vcan0 ERROR
 
-(1594172462.356874) vcan0 1F4#01020304 :: IO_DEBUG(IO_DEBUG_test_unsigned: 1, IO_DEBUG_test_enum: 'two', IO_DEBUG_test_signed: 3, IO_DEBUG_test_float: 2.0)
+(1594172462.356874) vcan0 1F4#01020304 :: IO_DEBUG(IO_DEBUG_test_unsigned: 1, IO_DEBUG_test_enum: two, IO_DEBUG_test_signed: 3, IO_DEBUG_test_float: 2.0)
 (1594172462.688432) vcan0 1F3#010203 :: Unknown frame id 499 (0x1f3)
 """
 
@@ -728,11 +741,11 @@ BATTERY_VT(
 
   ------------------------------------------------------------------------
 
-  Name:       ExampleMessage
-  Id:         0x1f0
-  Length:     8 bytes
-  Cycle time: - ms
-  Senders:    PCM1
+  Name:           ExampleMessage
+  Id:             0x1f0
+  Length:         8 bytes
+  Cycle time:     - ms
+  Senders:        PCM1
   Layout:
 
                           Bit
@@ -799,11 +812,11 @@ BATTERY_VT(
 
   ------------------------------------------------------------------------
 
-  Name:       ExampleMessage
-  Id:         0x1f0
-  Length:     8 bytes
-  Cycle time: - ms
-  Senders:    PCM1
+  Name:           ExampleMessage
+  Id:             0x1f0
+  Length:         8 bytes
+  Cycle time:     - ms
+  Senders:        PCM1
   Layout:
 
                           Bit
@@ -872,16 +885,16 @@ BATTERY_VT(
 
   ------------------------------------------------------------------------
 
-  Name:       Message1
-  Id:         0x123456
+  Name:           Message1
+  Id:             0x123456
       Priority:       0
       PGN:            0x01200
       Source:         0x56
       Destination:    0x34
       Format:         PDU 1
-  Length:     8 bytes
-  Cycle time: - ms
-  Senders:    -
+  Length:         8 bytes
+  Cycle time:     - ms
+  Senders:        -
   Layout:
 
                           Bit
@@ -972,11 +985,11 @@ BATTERY_VT(
 
   ------------------------------------------------------------------------
 
-  Name:       Foo
-  Id:         0x1d8
-  Length:     1 bytes
-  Cycle time: - ms
-  Senders:    -
+  Name:           Foo
+  Id:             0x1d8
+  Length:         1 bytes
+  Cycle time:     - ms
+  Senders:        -
   Layout:
 
                           Bit
@@ -1008,6 +1021,7 @@ BATTERY_VT(
         argv = [
             'cantools',
             'dump',
+            '--prune',
             'tests/files/dbc/dump_signal_choices.dbc'
         ]
 
@@ -1016,11 +1030,11 @@ BATTERY_VT(
 
   ------------------------------------------------------------------------
 
-  Name:       Message0
-  Id:         0x400
-  Length:     8 bytes
-  Cycle time: - ms
-  Senders:    Node0
+  Name:           Message0
+  Id:             0x400
+  Length:         8 bytes
+  Cycle time:     - ms
+  Senders:        Node0
   Layout:
 
                           Bit
@@ -1094,16 +1108,16 @@ BATTERY_VT(
 
   ------------------------------------------------------------------------
 
-  Name:       Message1
-  Id:         0x15340201
+  Name:           Message1
+  Id:             0x15340201
       Priority:       5
       PGN:            0x13400
       Source:         0x01
       Destination:    0x02
       Format:         PDU 1
-  Length:     8 bytes
-  Cycle time: - ms
-  Senders:    Node1
+  Length:         8 bytes
+  Cycle time:     - ms
+  Senders:        Node1
   Layout:
 
                           Bit
@@ -1136,16 +1150,16 @@ BATTERY_VT(
 
   ------------------------------------------------------------------------
 
-  Name:       Message2
-  Id:         0x15f01002
+  Name:           Message2
+  Id:             0x15f01002
       Priority:       5
       PGN:            0x1f010
       Source:         0x02
       Destination:    All
       Format:         PDU 2
-  Length:     8 bytes
-  Cycle time: - ms
-  Senders:    Node2
+  Length:         8 bytes
+  Cycle time:     - ms
+  Senders:        Node2
   Layout:
 
                           Bit
@@ -1246,6 +1260,7 @@ BATTERY_VT(
             'padding_bit_order',
             'vehicle',
             'floating_point',
+            'floating_point_use_float',
             'no_signals',
             'choices',
             'multiplex',
@@ -1266,6 +1281,8 @@ BATTERY_VT(
                 'generate_c_source',
                 'tests/files/dbc/{}.dbc'.format(database)
             ]
+            if database == 'floating_point_use_float':
+                argv.insert(-1, '--use-float')
 
             database_h = basename + '.h'
             database_c = basename + '.c'
