@@ -122,18 +122,18 @@ class CanToolsDumpTest(unittest.TestCase):
             formatting.signal_tree_string(message_2),
             '-- {root}\n'
             '   +-- Multiplexor\n'
-            '       +-- 4\n'
-            '       +-- 8\n'
+            '       +-- MULTIPLEXOR_4_NO_SIGNALS (4)\n'
+            '       +-- MULTIPLEXOR_8 (8)\n'
             '       |   +-- BIT_J\n'
             '       |   +-- BIT_C\n'
             '       |   +-- BIT_G\n'
             '       |   +-- BIT_L\n'
-            '       +-- 16\n'
+            '       +-- MULTIPLEXOR_16 (16)\n'
             '       |   +-- BIT_J\n'
             '       |   +-- BIT_C\n'
             '       |   +-- BIT_G\n'
             '       |   +-- BIT_L\n'
-            '       +-- 24\n'
+            '       +-- MULTIPLEXOR_24 (24)\n'
             '           +-- BIT_J\n'
             '           +-- BIT_C\n'
             '           +-- BIT_G\n'
