@@ -23,7 +23,7 @@ class Args(object):
         self.database = database
         self.encoding = None
         self.frame_id_mask = None
-        self.no_prune = False
+        self.prune = False
         self.no_strict = False
         self.single_line = single_line
         self.bit_rate = None
@@ -190,7 +190,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                      '   TIMESTAMP  MESSAGE                                           ',
                      'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -240,7 +240,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                      'green'),
                 call(2,
                      0,
-                     "       0.000  ExampleMessage(Enable: 'Enabled' -, "
+                     "       0.000  ExampleMessage(Enable: Enabled, "
                      "AverageRadius: 3.2 m, Temperature: 250.55 degK)"),
                 call(29,
                      0,
@@ -281,14 +281,9 @@ class CanToolsMonitorTest(unittest.TestCase):
             stdscr.addstr,
             [
                 call(0, 0, 'Received: 1, Discarded: 1, Errors: 0'),
-                call(1,
-                     0,
-                     '   TIMESTAMP  MESSAGE                                           ',
-                     'green'),
-                call(29,
-                     0,
-                     'q: Quit, f: Filter, p: Play/Pause, r: Reset                     ',
-                     'cyan')
+                call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
+                call(2, 0, '       0.000 BATTERY_VT ( undecoded: 0x240098980b00 )'),
+                call(29, 0, 'q: Quit, f: Filter, p: Play/Pause, r: Reset                     ', 'cyan')
             ])
 
     @patch('can.Notifier')
@@ -499,7 +494,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                      '   TIMESTAMP  MESSAGE                                           ',
                      'green'),
                 call(2, 0, '       1.100  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.54 degK'),
                 call(6, 0, '              )'),
@@ -547,7 +542,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -557,7 +552,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -576,7 +571,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0, Filter: Y['),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -607,7 +602,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -619,7 +614,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0, Filter: E'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -631,7 +626,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0, Filter: E'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -712,7 +707,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 2, Discarded: 1, Errors: 0'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -722,7 +717,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 2, Discarded: 1, Errors: 0'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -734,7 +729,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 2, Discarded: 1, Errors: 0, Filter: E'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -746,7 +741,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 3, Discarded: 1, Errors: 0, Filter: E'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       4.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.54 degK'),
                 call(6, 0, '              )'),
@@ -763,7 +758,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.48 degK'),
                 call(6, 0, '              )'),
@@ -775,7 +770,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0'),
                 call(1, 0, '   TIMESTAMP  MESSAGE                                           ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.48 degK'),
                 call(6, 0, '              )'),
@@ -844,7 +839,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                      '   TIMESTAMP  MESSAGE                                           ',
                      'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -859,7 +854,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                      '   TIMESTAMP  MESSAGE                                           ',
                      'green'),
                 call(2, 0, '       1.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -874,7 +869,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                      '   TIMESTAMP  MESSAGE                                           ',
                      'green'),
                 call(2, 0, '       2.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -890,7 +885,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                      '   TIMESTAMP  MESSAGE                                           ',
                      'green'),
                 call(2, 0, '       3.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -906,7 +901,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                      '   TIMESTAMP  MESSAGE                                           ',
                      'green'),
                 call(2, 0, '       5.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -921,7 +916,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                      '   TIMESTAMP  MESSAGE                                           ',
                      'green'),
                 call(2, 0, '       6.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -972,7 +967,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0'),
                 call(1, 0, '   TIMESTAMP  MESSAGE              ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -982,7 +977,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0'),
                 call(1, 0, '   TIMESTAMP  MESSAGE              ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
@@ -992,7 +987,7 @@ class CanToolsMonitorTest(unittest.TestCase):
                 call(0, 0, 'Received: 1, Discarded: 0, Errors: 0'),
                 call(1, 0, '   TIMESTAMP  MESSAGE         ', 'green'),
                 call(2, 0, '       0.000  ExampleMessage('),
-                call(3, 0, "                  Enable: 'Enabled' -,"),
+                call(3, 0, "                  Enable: Enabled,"),
                 call(4, 0, '                  AverageRadius: 3.2 m,'),
                 call(5, 0, '                  Temperature: 250.55 degK'),
                 call(6, 0, '              )'),
